@@ -33,11 +33,9 @@ import os
 import psutil
 import re
 import sys
-import tempfile
 import textwrap
 import time
 from distutils.util import strtobool
-from urllib.parse import urlparse
 
 from codalab.client.json_api_client import JsonApiClient
 from codalab.common import CODALAB_VERSION, PermissionError, UsageError
@@ -343,6 +341,14 @@ class CodaLabManager(object):
                 root_user_id=self.root_user_id(),
                 system_user_id=self.system_user_id(),
             )
+        elif model_class == 'SQLiteModel':
+            from codalab.model.sqlite_model import SQLiteModel
+
+            model = SQLiteModel(
+                default_user_info=self.default_user_info(),
+                root_user_id=self.root_user_id(),
+                system_user_id=self.system_user_id(),
+            )
         else:
             raise UsageError('Unexpected model class: %s, expected MySQLModel' % (model_class,))
         return model
