@@ -21,6 +21,7 @@ class User(ORMObject):
         'first_name',
         'last_name',
         'date_joined',
+        'has_access',
         'is_verified',
         'is_superuser',
         'password',
@@ -136,6 +137,7 @@ PUBLIC_USER = User(
         "first_name": None,
         "last_name": None,
         "date_joined": None,
+        "has_access": False,
         "is_verified": True,
         "is_superuser": False,
         "password": None,
