@@ -6,7 +6,7 @@ import http.client
 import json
 from datetime import datetime
 
-from bottle import abort, get, local, post, put, request, response
+from bottle import abort, get, local, post, request, response
 
 from codalab.lib import spec_util
 from codalab.objects.permission import check_bundle_have_run_permission
